package com.example.kdan_data_center.datacenter

import com.example.kdan_data_center.BuildConfig
import com.example.kdan_data_center.KdanCloud
import com.example.kdan_data_center.datacenter.file.FileService
import com.example.kdan_data_center.datacenter.folder.FolderService
import com.example.kdan_data_center.datacenter.share.ShareLinkService
import com.example.kdan_data_center.datacenter.user.UserService

class DataCenter(private val kdanCloud: KdanCloud) {
    companion object {
        const val DEBUG_HOST = "https://preparing.kdanmobile.com:3020/"
        const val RELEASE_HOST = "https://data-center-rails.kdanmobile.com/"
    }

    private val host = if (KdanCloud.ENV_DEV) DEBUG_HOST else RELEASE_HOST

    val userService: UserService = buildUserService()
    val fileService: FileService = buildFileService()
    val folderService: FolderService = buildFolderService()
    val shareLinkService: ShareLinkService = buildShareLinkService()

    private fun buildUserService(): UserService =
            kdanCloud.getRetrofit(host + UserService.BASE_URL).create(UserService::class.java)

    private fun buildFileService(): FileService =
            kdanCloud.getRetrofit(host + FileService.BASE_URL).create(FileService::class.java)

    private fun buildFolderService(): FolderService =
            kdanCloud.getRetrofit(host + FolderService.BASE_URL).create(FolderService::class.java)

    private fun buildShareLinkService(): ShareLinkService =
            kdanCloud.getRetrofit(host + ShareLinkService.BASE_URL).create(ShareLinkService::class.java)
}