package com.example.kdan_data_center.datacenter.folder

import com.example.kdan_data_center.datacenter.folder.body.*
import com.example.kdan_data_center.datacenter.folder.data.*
import io.reactivex.Observable
import retrofit2.http.*

interface FolderService {
    companion object {
        const val BASE_URL = "api/v3/folders/"
    }

    @POST(".")
    fun createFolder(
            @Header("Authorization") accessToken: String,
            @Header("Content-Type") contentType: String,
            @Body createFolderByNameBody: CreateFolderByNameBody
    ): Observable<CreateFolderData>

    @POST("recursive_create")
    fun createFolder(
            @Header("Authorization") accessToken: String,
            @Header("Content-Type") contentType: String,
            @Body createFolderByPathBody: CreateFolderByPathBody
    ): Observable<CreateFolderData>

    @GET(".")
    fun getFolderInfo(
            @Header("Authorization") accessToken: String,
            @Query("folder_id") folderId: Int?,
            @Query("depth") depth: Int?,
            @Query("category") category: String?,
            @Query("app_series") appSeries: String?
    ): Observable<FolderInfoData>

    @PUT(".")
    fun updateFolder(
            @Header("Authorization") accessToken: String,
            @Header("Content-Type") contentType: String,
            @Body updateFolderBody: UpdateFolderBody
    ): Observable<UpdateFolderData>

    @HTTP(method = "DELETE", path = ".", hasBody = true)
    @FormUrlEncoded
    fun deleteFolder(
            @Header("Authorization") accessToken: String,
            @Field("folder_id") folderId: Int
    ): Observable<DeleteFolderData>

    @HTTP(method = "DELETE", path = ".", hasBody = true)
    @FormUrlEncoded
    fun deleteFolder(
            @Header("Authorization") accessToken: String,
            @Field("folder_id_list[]") folderIdList: IntArray
    ): Observable<DeleteFolderData>

    @HTTP(method = "DELETE", path = "hard_destroy", hasBody = true)
    @FormUrlEncoded
    fun hardDeleteFolder(
            @Header("Authorization") accessToken: String,
            @Field("folder_id") folderId: Int
    ): Observable<DeleteFolderData>

    @HTTP(method = "DELETE", path = "hard_destroy", hasBody = true)
    @FormUrlEncoded
    fun hardDeleteFolder(
            @Header("Authorization") accessToken: String,
            @Field("folder_id_list[]") folderIdList: IntArray
    ): Observable<DeleteFolderData>

    @PUT("restore")
    @FormUrlEncoded
    fun restoreFolder(
            @Header("Authorization") accessToken: String,
            @Field("folder_id") folderId: Int
    ): Observable<FolderInfoData>

    @PUT("restore")
    @FormUrlEncoded
    fun restoreFolder(
            @Header("Authorization") accessToken: String,
            @Field("folder_id_list[]") folderIdList: IntArray
    ): Observable<FolderInfoData>

    @POST("copy")
    @FormUrlEncoded
    fun copyFolder(
            @Header("Authorization") accessToken: String,
            @Field("parent_id") parentId: Int?,
            @Field("folder_id") folderId: Int
    ): Observable<FolderInfoData>

    @POST("copy")
    @FormUrlEncoded
    fun copyFolder(
            @Header("Authorization") accessToken: String,
            @Field("parent_id") parentId: Int?,
            @Field("folder_id_list[]") folderIdList: IntArray
    ): Observable<FolderInfoData>

    @PUT("move")
    @FormUrlEncoded
    fun moveFolder(
            @Header("Authorization") accessToken: String,
            @Field("parent_id") parentId: Int?,
            @Field("folder_id") folderId: Int
    ): Observable<FolderInfoData>

    @PUT("move")
    @FormUrlEncoded
    fun moveFolder(
            @Header("Authorization") accessToken: String,
            @Field("parent_id") parentId: Int?,
            @Field("folder_id_list[]") folderIdList: IntArray
    ): Observable<FolderInfoData>

    @PUT("sync_architecture")
    fun syncFolder(
            @Header("Authorization") accessToken: String,
            @Header("Content-Type") contentType: String,
            @Body syncFolderBody: SyncFolderBody
    ): Observable<SyncFolderData>
}